<?php

namespace WPMailSMTP\Vendor;

/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
/**
 * Service definition for Gmail (v1).
 *
 * <p>
 * The Gmail API lets you view and manage Gmail mailbox data like threads,
 * messages, and labels.</p>
 *
 * <p>
 * For more information about this service, see the API
 * <a href="https://developers.google.com/gmail/api/" target="_blank">Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
class Google_Service_Gmail extends \WPMailSMTP\Vendor\Google_Service
{
    /** Read, compose, send, and permanently delete all your email from Gmail. */
    const MAIL_GOOGLE_COM = "https://mail.google.com/";
    /** Manage drafts and send emails when you interact with the add-on. */
    const GMAIL_ADDONS_CURRENT_ACTION_COMPOSE = "https://www.googleapis.com/auth/gmail.addons.current.action.compose";
    /** View your email messages when you interact with the add-on. */
    const GMAIL_ADDONS_CURRENT_MESSAGE_ACTION = "https://www.googleapis.com/auth/gmail.addons.current.message.action";
    /** View your email message metadata when the add-on is running. */
    const GMAIL_ADDONS_CURRENT_MESSAGE_METADATA = "https://www.googleapis.com/auth/gmail.addons.current.message.metadata";
    /** View your email messages when the add-on is running. */
    const GMAIL_ADDONS_CURRENT_MESSAGE_READONLY = "https://www.googleapis.com/auth/gmail.addons.current.message.readonly";
    /** Manage drafts and send emails. */
    const GMAIL_COMPOSE = "https://www.googleapis.com/auth/gmail.compose";
    /** Insert mail into your mailbox. */
    const GMAIL_INSERT = "https://www.googleapis.com/auth/gmail.insert";
    /** Manage mailbox labels. */
    const GMAIL_LABELS = "https://www.googleapis.com/auth/gmail.labels";
    /** View your email message metadata such as labels and headers, but not the email body. */
    const GMAIL_METADATA = "https://www.googleapis.com/auth/gmail.metadata";
    /** View and modify but not delete your email. */
    const GMAIL_MODIFY = "https://www.googleapis.com/auth/gmail.modify";
    /** View your email messages and settings. */
    const GMAIL_READONLY = "https://www.googleapis.com/auth/gmail.readonly";
    /** Send email on your behalf. */
    const GMAIL_SEND = "https://www.googleapis.com/auth/gmail.send";
    /** Manage your basic mail settings. */
    const GMAIL_SETTINGS_BASIC = "https://www.googleapis.com/auth/gmail.settings.basic";
    /** Manage your sensitive mail settings, including who can manage your mail. */
    const GMAIL_SETTINGS_SHARING = "https://www.googleapis.com/auth/gmail.settings.sharing";
    public $users;
    public $users_drafts;
    public $users_history;
    public $users_labels;
    public $users_messages;
    public $users_messages_attachments;
    public $users_settings;
    public $users_settings_delegates;
    public $users_settings_filters;
    public $users_settings_forwardingAddresses;
    public $users_settings_sendAs;
    public $users_settings_sendAs_smimeInfo;
    public $users_threads;
    /**
     * Constructs the internal representation of the Gmail service.
     *
     * @param Google_Client $client The client used to deliver requests.
     * @param string $rootUrl The root URL used for requests to the service.
     */
    public function __construct(\WPMailSMTP\Vendor\Google_Client $client, $rootUrl = null)
    {
        parent::__construct($client);
        $this->rootUrl = $rootUrl ?: 'https://gmail.googleapis.com/';
        $this->servicePath = '';
        $this->batchPath = 'batch';
        $this->version = 'v1';
        $this->serviceName = 'gmail';
        $this->users = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_Users($this, $this->serviceName, 'users', array('methods' => array('getProfile' => array('path' => 'gmail/v1/users/{userId}/profile', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'stop' => array('path' => 'gmail/v1/users/{userId}/stop', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'watch' => array('path' => 'gmail/v1/users/{userId}/watch', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_drafts = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersDrafts($this, $this->serviceName, 'drafts', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/drafts', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/drafts/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/drafts/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'format' => array('location' => 'query', 'type' => 'string'))), 'list' => array('path' => 'gmail/v1/users/{userId}/drafts', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'q' => array('location' => 'query', 'type' => 'string'), 'pageToken' => array('location' => 'query', 'type' => 'string'), 'includeSpamTrash' => array('location' => 'query', 'type' => 'boolean'), 'maxResults' => array('location' => 'query', 'type' => 'integer'))), 'send' => array('path' => 'gmail/v1/users/{userId}/drafts/send', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'update' => array('path' => 'gmail/v1/users/{userId}/drafts/{id}', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_history = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersHistory($this, $this->serviceName, 'history', array('methods' => array('list' => array('path' => 'gmail/v1/users/{userId}/history', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'labelId' => array('location' => 'query', 'type' => 'string'), 'historyTypes' => array('location' => 'query', 'type' => 'string', 'repeated' => \true), 'startHistoryId' => array('location' => 'query', 'type' => 'string'), 'maxResults' => array('location' => 'query', 'type' => 'integer'), 'pageToken' => array('location' => 'query', 'type' => 'string'))))));
        $this->users_labels = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersLabels($this, $this->serviceName, 'labels', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/labels', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/labels/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/labels/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/labels', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'patch' => array('path' => 'gmail/v1/users/{userId}/labels/{id}', 'httpMethod' => 'PATCH', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'update' => array('path' => 'gmail/v1/users/{userId}/labels/{id}', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_messages = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersMessages($this, $this->serviceName, 'messages', array('methods' => array('batchDelete' => array('path' => 'gmail/v1/users/{userId}/messages/batchDelete', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'batchModify' => array('path' => 'gmail/v1/users/{userId}/messages/batchModify', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/messages/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/messages/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'metadataHeaders' => array('location' => 'query', 'type' => 'string', 'repeated' => \true), 'format' => array('location' => 'query', 'type' => 'string'))), 'import' => array('path' => 'gmail/v1/users/{userId}/messages/import', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'neverMarkSpam' => array('location' => 'query', 'type' => 'boolean'), 'processForCalendar' => array('location' => 'query', 'type' => 'boolean'), 'deleted' => array('location' => 'query', 'type' => 'boolean'), 'internalDateSource' => array('location' => 'query', 'type' => 'string'))), 'insert' => array('path' => 'gmail/v1/users/{userId}/messages', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'deleted' => array('location' => 'query', 'type' => 'boolean'), 'internalDateSource' => array('location' => 'query', 'type' => 'string'))), 'list' => array('path' => 'gmail/v1/users/{userId}/messages', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'q' => array('location' => 'query', 'type' => 'string'), 'includeSpamTrash' => array('location' => 'query', 'type' => 'boolean'), 'maxResults' => array('location' => 'query', 'type' => 'integer'), 'labelIds' => array('location' => 'query', 'type' => 'string', 'repeated' => \true), 'pageToken' => array('location' => 'query', 'type' => 'string'))), 'modify' => array('path' => 'gmail/v1/users/{userId}/messages/{id}/modify', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'send' => array('path' => 'gmail/v1/users/{userId}/messages/send', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'trash' => array('path' => 'gmail/v1/users/{userId}/messages/{id}/trash', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'untrash' => array('path' => 'gmail/v1/users/{userId}/messages/{id}/untrash', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_messages_attachments = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersMessagesAttachments($this, $this->serviceName, 'attachments', array('methods' => array('get' => array('path' => 'gmail/v1/users/{userId}/messages/{messageId}/attachments/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'messageId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettings($this, $this->serviceName, 'settings', array('methods' => array('getAutoForwarding' => array('path' => 'gmail/v1/users/{userId}/settings/autoForwarding', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'getImap' => array('path' => 'gmail/v1/users/{userId}/settings/imap', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'getLanguage' => array('path' => 'gmail/v1/users/{userId}/settings/language', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'getPop' => array('path' => 'gmail/v1/users/{userId}/settings/pop', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'getVacation' => array('path' => 'gmail/v1/users/{userId}/settings/vacation', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'updateAutoForwarding' => array('path' => 'gmail/v1/users/{userId}/settings/autoForwarding', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'updateImap' => array('path' => 'gmail/v1/users/{userId}/settings/imap', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'updateLanguage' => array('path' => 'gmail/v1/users/{userId}/settings/language', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'updatePop' => array('path' => 'gmail/v1/users/{userId}/settings/pop', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'updateVacation' => array('path' => 'gmail/v1/users/{userId}/settings/vacation', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings_delegates = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettingsDelegates($this, $this->serviceName, 'delegates', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/settings/delegates', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/settings/delegates/{delegateEmail}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'delegateEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/settings/delegates/{delegateEmail}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'delegateEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/settings/delegates', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings_filters = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettingsFilters($this, $this->serviceName, 'filters', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/settings/filters', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/settings/filters/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/settings/filters/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/settings/filters', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings_forwardingAddresses = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettingsForwardingAddresses($this, $this->serviceName, 'forwardingAddresses', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/settings/forwardingAddresses', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/settings/forwardingAddresses/{forwardingEmail}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'forwardingEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/settings/forwardingAddresses/{forwardingEmail}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'forwardingEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/settings/forwardingAddresses', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings_sendAs = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettingsSendAs($this, $this->serviceName, 'sendAs', array('methods' => array('create' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'delete' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'patch' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}', 'httpMethod' => 'PATCH', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'update' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}', 'httpMethod' => 'PUT', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'verify' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/verify', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_settings_sendAs_smimeInfo = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersSettingsSendAsSmimeInfo($this, $this->serviceName, 'smimeInfo', array('methods' => array('delete' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/smimeInfo/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/smimeInfo/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'insert' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/smimeInfo', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'list' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/smimeInfo', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'setDefault' => array('path' => 'gmail/v1/users/{userId}/settings/sendAs/{sendAsEmail}/smimeInfo/{id}/setDefault', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'sendAsEmail' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
        $this->users_threads = new \WPMailSMTP\Vendor\Google_Service_Gmail_Resource_UsersThreads($this, $this->serviceName, 'threads', array('methods' => array('delete' => array('path' => 'gmail/v1/users/{userId}/threads/{id}', 'httpMethod' => 'DELETE', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'get' => array('path' => 'gmail/v1/users/{userId}/threads/{id}', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'metadataHeaders' => array('location' => 'query', 'type' => 'string', 'repeated' => \true), 'format' => array('location' => 'query', 'type' => 'string'))), 'list' => array('path' => 'gmail/v1/users/{userId}/threads', 'httpMethod' => 'GET', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'maxResults' => array('location' => 'query', 'type' => 'integer'), 'pageToken' => array('location' => 'query', 'type' => 'string'), 'q' => array('location' => 'query', 'type' => 'string'), 'labelIds' => array('location' => 'query', 'type' => 'string', 'repeated' => \true), 'includeSpamTrash' => array('location' => 'query', 'type' => 'boolean'))), 'modify' => array('path' => 'gmail/v1/users/{userId}/threads/{id}/modify', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'trash' => array('path' => 'gmail/v1/users/{userId}/threads/{id}/trash', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))), 'untrash' => array('path' => 'gmail/v1/users/{userId}/threads/{id}/untrash', 'httpMethod' => 'POST', 'parameters' => array('userId' => array('location' => 'path', 'type' => 'string', 'required' => \true), 'id' => array('location' => 'path', 'type' => 'string', 'required' => \true))))));
    }
}
